@@ -10,19 +10,46 @@
 
 #include "kitawritedialog.h"
 #include "libkita/qcp932codec.h"
+#include "libkita/thread.h"
 #include "kitaconfig.h"
+#include "kita2ch.h"
 
 #include <ksqueezedtextlabel.h>
 #include <klocale.h>
 #include <kdebug.h>
+#include <kstandarddirs.h>
 
 #include <qlineedit.h>
 #include <qtextedit.h>
 #include <qpushbutton.h>
 #include <qlabel.h>
+#include <qcombobox.h>
+#include <qeucjpcodec.h>
+#include <qfile.h>
 
 #include <kio/job.h>
 
+const char* kaomoji[] = {
+  "",
+  "(ߢώ)!!!!!",
+  "ʎߧՎߡˎώ",
+  "(++)ώގ",
+  "((((((ߧ))))))ގގ̎ގَ̎ގ",
+  "(ء`)Ύގ",
+  "( _`)̎",
+  "(`)Ύ܎",
+  "ʎώˎ!!",
+  "(;`)ʎʎ",
+//  "(?)׎",
+  "(ߧ)ʎ?",
+  "ߎ(ɧ`)ߎ",
+  "(ߧՎ)Ύߎ",
+  "ʡϡˎ!!",
+  "(-`).()",
+  "(ҡϡ)Ҏގ",
+  NULL
+};
+
 KitaWriteDialogPrivate * KitaWriteDialog::s_private = 0;
 
 KitaWriteDialog::KitaWriteDialog(QWidget *parent, const char *name)
@@ -34,6 +61,15 @@ KitaWriteDialog::KitaWriteDialog(QWidget *parent, const char *name)
   nameLabel->setFont( font );
   mailLine->setFont( font );
   mailLabel->setFont( font );
+
+  faceCombo->clear();
+  int i=0;
+  while( kaomoji[i] ) {
+    QEucJpCodec codec;
+    QString str = codec.toUnicode( kaomoji[i], strlen( kaomoji[i] ) );
+    faceCombo->insertItem( str );
+    i++;
+  }
 }
 
 KitaWriteDialog::~KitaWriteDialog()
@@ -62,7 +98,9 @@ void KitaWriteDialog::fetchPostInfo( Kita::PostInfo * storage ) const
   storage->body = body();
 }
 
-KitaWriteDialog* KitaWriteDialog::open( const Kita::PostInfo& info, const QString& boardName, const QString& threadName )
+// TODO: Thread饹Ȥ褦˽񤭴
+KitaWriteDialog* KitaWriteDialog::open( const Kita::PostInfo& info,
+                                        const Kita::Thread& thread )
 {
   if ( ! info.check() ) return 0;
   if ( ! s_private ) {
@@ -83,13 +121,40 @@ KitaWriteDialog* KitaWriteDialog::open( const Kita::PostInfo& info, const QStrin
   new_dlg->mailLine->setText(info.mail);
   new_dlg->bodyText->setText(info.body);
 
-  new_dlg->boardNameLabel->setText( boardName );
-  new_dlg->threadNameLabel->setText( threadName );
+  new_dlg->boardNameLabel->setText( thread.boardName() );
+  new_dlg->threadNameLabel->setText( thread.name() );
+  new_dlg->threadURLLabel->setText( thread.url().url() );
 
-  new_dlg->setCaption( i18n("Write in %1").arg( threadName ) );
+  new_dlg->setCaption( i18n("Write in %1").arg( thread.name() ) );
   return new_dlg;
 }
 
+static void logPostMessage( const Kita::PostInfo& postInfo,
+                            const QString& boardName,
+                            const QString& threadName,
+                            const QString& threadURL )
+{
+  QDateTime now = QDateTime::currentDateTime();
+  QString logPath = locateLocal( "appdata", "log.txt" );
+
+  QFile file( logPath );
+  if ( file.open( IO_WriteOnly | IO_Append ) ) {
+    QTextStream stream( &file );
+    stream.setEncoding( QTextStream::UnicodeUTF8 );
+
+    stream << "Date   : " << now.toString( "yyyy/MM/dd hh:mm:ss" ) << endl; // ߻
+    stream << "Board  : " << boardName << endl;
+    stream << "Thread : " << threadName << endl;
+    stream << "URL    : " << threadURL << endl;
+    stream << "Name   : " << postInfo.name << endl;
+    stream << "Mail   : " << postInfo.mail << endl << endl;
+    stream << postInfo.body << endl;
+    stream << "----------------------------------------" << endl;
+
+    file.close();
+  }
+}
+
 void KitaWriteDialog::postMessage()
 {
   fetchPostInfo( &m_postInfo );
@@ -114,6 +179,9 @@ void KitaWriteDialog::postMessage()
   if ( ! m_postInfo.cookie.isEmpty() )
 	  job->addMetaData("cookie", m_postInfo.cookie.prepend("Cookie: "));
 
+  // TODO: rewrite!
+  logPostMessage( m_postInfo, boardNameLabel->text(), threadNameLabel->text(), threadURLLabel->text() );
+
   emit postStarted( job, m_postInfo );
 
   connect( job, SIGNAL( data(KIO::Job*, const QByteArray&) ),
